@@ -68,13 +68,14 @@ setMethod("sigma.hat", signature(object = "glm"),
 
 
 
-setMethod("sigma.hat", signature(object = "mer"),
+setMethod("sigma.hat", signature(object = "merMod"),
     function(object)
     {
     #object <- summary (object)
     fcoef <- fixef(object)
     #useScale <- attr (VarCorr (object), "sc")  # =sc?
-    useScale <- object@dims["useSc"]
+    #useScale <- object@dims["useSc"]
+    useScale <- getME(object, "devcomp")$dims["useSc"]
     #ngrps <- lapply(object@flist, function(x) length(levels(x)))
     #n.groupings <- length (ngrps)
     varc <- VarCorr (object)
@@ -97,7 +98,7 @@ setMethod("sigma.hat", signature(object = "mer"),
 
 
 
-setMethod("sigma.hat", signature(object = "sim.mer"),
+setMethod("sigma.hat", signature(object = "sim.merMod"),
     function(object)
     {
     sigma <- object@sigma
